@@ -32,7 +32,11 @@ open XHTML_types
 module Version(XML : XML_sigs.T) = struct
 
   module XML = XML
-  include Uri
+
+  type uri = XML.uri
+  let string_of_uri = XML.string_of_uri
+  let uri_of_string = XML.uri_of_string
+
   (* Directly from http://www.w3.org/TR/xhtml-modularization/abstract_modules.html *)
 
   type core = [ `Class | `Id | `Title | `XML_space ]
@@ -52,7 +56,8 @@ module Version(XML : XML_sigs.T) = struct
 
   let int_attrib = XML.int_attrib
   let string_attrib = XML.string_attrib
-  let uri_attrib a b = XML.string_attrib a (string_of_uri b)
+  let uri_attrib = XML.uri_attrib
+  let uris_attrib = XML.uris_attrib
   let space_sep_attrib = XML.space_sep_attrib
   let comma_sep_attrib = XML.comma_sep_attrib
   let event_attrib = XML.event_attrib
@@ -155,7 +160,7 @@ module Version(XML : XML_sigs.T) = struct
 
   let a_class = space_sep_attrib "class"
       (* class is different on client side.
-         We put the value in xML.ml 
+         We put the value in xML.ml
          because this file has a different implementation client side.
        *)
   let a_id = string_attrib "id"
@@ -336,7 +341,7 @@ module Version(XML : XML_sigs.T) = struct
   let a_codebase = uri_attrib "codebase"
   let a_data = uri_attrib "data"
   let a_codetype = string_attrib "codetype"
-  let a_archive = uri_attrib "archive"
+  let a_archive = uris_attrib "archive"
   let a_standby = string_attrib "standby"
 
   let a_fs_rows mls = multilengths_attrib "rows" mls
@@ -763,21 +768,31 @@ module Version(XML : XML_sigs.T) = struct
 
 end
 
+(* The following tags are written <br />, etc.
+   The other empty tags are written <p></p> for html compatibility.
+   See guidelines here:
+   http://www.w3.org/TR/xhtml1/#guidelines
+ *)
+let emptytags =
+  [ "hr"; "br"; "img"; "meta"; "link"; "input"; "col"; "area";
+    "param"; "base"; "basefont"; "isindex"; "frame" ]
+
 module Make_01_00(XML : XML_sigs.T) = struct
 
   module M = Version(XML)
   include M
 
   module Info = struct
-    let content_type = "text/xml"
+    let content_type = "text/html"
+    let alternative_content_types = ["application/xhtml+xml"]
     let version = "XHTML 1.0"
-    let standard = Uri.uri_of_string "http://www.w3.org/TR/xhtml1/"
+    let standard = "http://www.w3.org/TR/xhtml1/"
+    let namespace = "http://www.w3.org/1999/xhtml"
     let doctype =
-      XML_print.compose_decl () ^
       XML_print.compose_doctype	"html"
 	["-//W3C//DTD XHTML 1.0 Strict//EN";
 	 "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"]
-    let emptytags = []
+    let emptytags = emptytags
   end
 
 end
@@ -788,63 +803,19 @@ module Make_01_01(XML : XML_sigs.T) = struct
   include M
 
   module Info = struct
-    let content_type = "text/xml"
+    let content_type = "text/html"
+    let alternative_content_types = ["application/xhtml+xml"]
     let version = "XHTML 1.1"
-    let standard = Uri.uri_of_string "http://www.w3.org/TR/xhtml11/"
+    let standard = "http://www.w3.org/TR/xhtml11/"
+    let namespace = "http://www.w3.org/1999/xhtml"
     let doctype =
       XML_print.compose_decl () ^
       XML_print.compose_doctype "html"
 	["-//W3C//DTD XHTML 1.1//EN";
 	 "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd"]
-    let emptytags = []
-  end
-
-end
-
-(* The following tags are written <br />, etc.
-   The other empty tags are written <p></p> for html compatibility.
-   See guidelines here:
-   http://www.w3.org/TR/xhtml1/#guidelines
- *)
-let emptytags =
-  [ "hr"; "br"; "img"; "meta"; "link"; "input"; "col"; "area";
-    "param"; "base"; "basefont"; "isindex"; "frame" ]
-
-
-module Make_01_00_compat(XML : XML_sigs.T) = struct
-
-  module M = Version(XML)
-  include M
-
-  module Info = struct
-    let content_type = "text/html"
-    let version = "XHTML 1.0"
-    let standard = Uri.uri_of_string "http://www.w3.org/TR/xhtml1/"
-    let doctype =
-      XML_print.compose_doctype "html"
-	["-//W3C//DTD XHTML 1.0//EN";
-	 "http://www.w3.org/TR/xhtml11/DTD/xhtml1.dtd"]
     let emptytags = emptytags
   end
 
 end
 
-module Make_01_01_compat(XML : XML_sigs.T) = struct
-
-  module M = Version(XML)
-  include M
-
-  module Info = struct
-    let content_type = "text/html"
-    let version = "XHTML 1.1"
-    let standard = Uri.uri_of_string "http://www.w3.org/TR/xhtml11/"
-    let doctype =
-      XML_print.compose_doctype "html"
-	["-//W3C//DTD XHTML 1.1//EN";
-	 "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd"]
-    let emptytags = emptytags
-  end
-
-end
-
-module Make = Make_01_01_compat
+module Make = Make_01_01
